#!/bin/bash
#
# Source : http://michael.toren.net/code/tcptraceroute/tcptraceroute-1.5beta7.tar.gz
# Maintainer : Son|c <emmanuel.bailleul@cegetel.net>
#


#------------------( Set Package Variables )


soft='tcptraceroute'
softversion='1.5beta7'
packageversion='48.1'


#------------------( Set Architecture Variables )

arch='i486'
cpu='i686'


#------------------( Set Architecture Variables )


buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"


#------------------( Prepare The Work Area And Source Package )


cd $buildir
rm -f {$dest,$dest.dep,$dest.md5,$dest.tgz,$package,$package.md5,$src} 1>/dev/null 2>&1
tar -xvzf $srcpkg
mkdir -p $dest


#------------------( Set Build Ownerships, Permissions and CFLAGS )


    chown -R root:root . 
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu" 
export CXXFLAGS="$CFLAGS"


#------------------( Set Configuration Options )

cd $src
./configure --prefix=/usr --datadir=/usr


#------------------( Make and Install Software )


make
make install DESTDIR=$dest


#------------------(  Relocate doc )

mv $dest/usr/doc/tcptraceroute $dest/usr/doc/tcptraceroute-1.5beta7


#------------------ Strip Executables (Comment out these lines if debugging info is needed) )


cd $dest
chown -R root:root $dest/usr/bin
( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)


##------------------( Move Documentation To Correct Location )
#
#
#cd $src
#mkdir -p $dest/usr/doc/$soft-$softversion
#cp -a \
#  AUTHORS COPYING ChangeLog INSTALL NEWS README TODO \
#  $dest/usr/doc/$soft-$softversion


#------------------( Copy The Build Script )

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( Create and Install The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc 
    |-----handy-ruler------------------------------------------------------|
tcptraceroute: Enhanced traceroute tool
tcptraceroute:
tcptraceroute: tcptraceroute is a traceroute implementation using TCP
tcptraceroute: packets
tcptraceroute:
tcptraceroute:
tcptraceroute:
tcptraceroute:
tcptraceroute:
tcptraceroute:
tcptraceroute:
EOF


#------------------( Compress Man Pages )

( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)


#------------------( Create The *.dep File )


cd $dest
requiredbuilder -z $dest > $buildir/$package.dep

#------------------( Compress The Package And Clean Up The Work Area )


cd $dest
makepkg -l y -c n $package.tgz
mv $package.tgz ../$package.tgz
rm -rf $src
rm -rf $dest


#------------------( Generate the MD5 Check Sum )


cd $buildir
rm -f $package.md5
md5sum $package.tgz > $package.md5

